@@ -6,7 +6,7 @@
 from __future__ import annotations
 
 # These are for typing our methods:
-from typing import List, Tuple, Union, TYPE_CHECKING
+from typing import Any, Callable, List, Tuple, Union, TYPE_CHECKING
 
 
 # These ones are internal to `violetear`:
@@ -41,7 +41,7 @@ import textwrap
 
 class Style:
     def __init__(
-        self, selector: Union[str, Selector] = None, *, parent: Style = None
+        self, selector: Union[str, Selector] = None, *, parent: Style = None, owner=None
     ) -> None:
         """Create a new instance of `Style`.
 
@@ -56,11 +56,11 @@ class Style:
             selector = Selector.parse(selector)
 
         self.selector = selector
-        self._rules = {}
         self._parent = parent
+        self._rules = {}
         self._children = {}
-        self._transitions = []
         self._transforms = {}
+        self._transitions = []
         self._animations = set()
         self._animation_configs = []
 
@@ -691,14 +691,10 @@ class Style:
     # #### `Style.css`
 
     def css(self, inline: bool = False) -> str:
-        separator = "" if inline else "\n"
-
-        rules = separator.join(
-            f"{attr}: {value};" for attr, value in self._rules.items()
-        )
-
         if inline:
-            return rules
+            return "; ".join(f"{attr}: {value}" for attr, value in self._rules.items())
+
+        rules = "\n".join(f"{attr}: {value};" for attr, value in self._rules.items())
 
         selector = self.selector.css() if self.selector is not None else ""
         return f"{selector} {{\n{textwrap.indent(rules, 4*' ')}\n}}"
@@ -713,7 +709,7 @@ class Style:
     def markup(self) -> str:
         return self.selector.markup()
 
-    # #### `Style.__str__`
+    # #### `Style.__bool__`
 
-    def __str__(self):
-        return self.markup()
+    def __bool__(self):
+        return len(self._rules) > 0
